pub struct IdTokenClaims {
pub iss: String,
pub aud: String,
pub iat: i64,
pub exp: i64,
pub auth_time: i64,
pub sub: String,
pub email: Option<String>,
pub email_verified: bool,
pub custom_claims: Map<String, Value>,
}Expand description
The decoded and verified claims of a Firebase ID token.
See https://firebase.google.com/docs/auth/admin/verify-id-tokens for the authoritative claim reference.
Fields
iss: StringThe token issuer, expected to be https://securetoken.google.com/<project-id>.
aud: StringThe intended audience, expected to equal the Firebase project ID.
iat: i64Issued-at time, in seconds since the Unix epoch.
exp: i64Expiration time, in seconds since the Unix epoch.
auth_time: i64The time the end user authenticated, in seconds since the Unix epoch.
sub: StringThe Firebase user id (UID) this token was issued for.
email: Option<String>The user’s email address, if available.
email_verified: boolWhether the user’s email address has been verified.
custom_claims: Map<String, Value>Custom claims attached to the user via set_custom_user_claims.