pub struct SessionCookieVerifier { /* private fields */ }Expand description
Verifies Firebase session cookies against Google’s session-cookie certificate endpoint and the project’s expected issuer/audience.
Implementations
Sourceimpl SessionCookieVerifier
impl SessionCookieVerifier
Sourcepub fn new(project_id: ProjectId, certs: SessionCookieCertCache) -> Self
pub fn new(project_id: ProjectId, certs: SessionCookieCertCache) -> Self
Creates a verifier for the given project, using the given cert cache.
Sourcepub async fn verify(
&self,
cookie: &str,
) -> Result<IdTokenClaims, TokenVerificationError>
pub async fn verify( &self, cookie: &str, ) -> Result<IdTokenClaims, TokenVerificationError>
Verifies a session cookie, returning its claims if every check
passes: signature, exp, iat/auth_time, aud, iss, and
non-empty sub.